@@ -1,5 +1,5 @@
 from datetime import datetime
-import json, os
+import json, shutil
 
 class printr:
     '''printr'''
@@ -19,7 +19,7 @@ class printr:
             current_time = current_time.strftime('%H:%M:%S:%f')
             message = f'{current_time}: {message}'
         if same_line:
-            terminal_size = os.get_terminal_size()
+            terminal_size = shutil.get_terminal_size()
             max_characters = terminal_size.columns - 1
             print(' ' * max_characters, end='') # Clear previous output
             print('\r', end='')
